@@ -19,7 +19,7 @@ The nifti package contains the following subpackages and modules:
 
 :author: `Michael Hanke <michael.hanke@gmail.com>`__
 :requires: Python 2.4+
-:version: 0.20080630.1
+:version: 0.20080710.1
 :see: `The PyNIfTI webpage <http://niftilib.sf.net/pynifti>`__
 :see: `GIT Repository Browser <http://git.debian.org/?p=pkg-exppsy/pynifti.git>`__
 
@@ -35,4 +35,4 @@ The nifti package contains the following subpackages and modules:
 __docformat__ = 'restructuredtext'
 
 
-from nifti.niftiimage import NiftiImage
+from niftiimage import NiftiImage
