@@ -12,9 +12,9 @@ __docformat__ = 'restructuredtext'
 
 
 # the swig wrapper if the NIfTI C library
-import nifti.nifticlib as nifticlib
-from nifti.niftiformat import NiftiFormat
-from nifti.utils import splitFilename, nifti2numpy_dtype_map
+import nifticlib
+from niftiformat import NiftiFormat
+from utils import splitFilename, nifti2numpy_dtype_map
 import numpy as N
 
 
@@ -442,7 +442,7 @@ class MemMappedNiftiImage(NiftiImage):
     def __del__(self):
         """Do all necessary cleanups by calling __close().
         """
-        self._data.sync()
+        self._data.flush()
 
         # it is required to call base class destructors!
         NiftiFormat.__del__(self)
@@ -458,7 +458,7 @@ class MemMappedNiftiImage(NiftiImage):
         class does not automatically update them, because it would require to
         load and search through the whole array.
         """
-        self._data.sync()
+        self._data.flush()
 
 
     def load(self):
@@ -480,3 +480,25 @@ class MemMappedNiftiImage(NiftiImage):
         raise RuntimeError, \
               "Filename modifications are not supported for memory mapped " \
               "images."
+
+
+def cropImage( nimg, bbox ):
+    """ Crop an image.
+
+    'bbox' has to be a sequency of (min,max) tuples (one for each image
+    dimension).
+
+    The function returns the cropped image. The data is not shared with the
+    original image, but is copied.
+    """
+
+    # build crop command
+    cmd = 'nimg.data.squeeze()['
+    cmd += ','.join( [ ':'.join( [ str(i) for i in dim ] ) for dim in bbox ] )
+    cmd += ']'
+
+    # crop the image data array
+    cropped = eval(cmd).copy()
+
+    # return the cropped image with preserved header data
+    return NiftiImage(cropped, nimg.header)
